@@ -20,9 +20,18 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
+import math
+from decimal import Decimal, ROUND_HALF_UP
+
+__version__ = '1.2.2'
 
 
-__version__ = '1.2.0'
+def school_math_round(num):
+    """
+    Try built in round(2.5) and then use this method instead... Why? Not sure,
+    but this is right, for the moment at least.
+    """
+    return int(Decimal(num).quantize(Decimal(1), rounding=ROUND_HALF_UP))
 
 
 class Timecode(object):
@@ -33,8 +42,9 @@ class Timecode(object):
     using the frame rate setting.
 
     :param framerate: The frame rate of the Timecode instance. It
-      should be one of ['23.98', '24', '25', '29.97', '30', '50', '59.94',
-      '60', 'NUMERATOR/DENOMINATOR', ms'] where "ms" equals to 1000 fps.
+      should be one of ['23.976', '23.98', '24', '25', '29.97', '30', '50',
+      '59.94', '60', 'NUMERATOR/DENOMINATOR', ms'] where "ms" equals to
+      1000 fps.
       Can not be skipped.
       Setting the framerate will automatically set the :attr:`.drop_frame`
       attribute to correct value.
@@ -52,11 +62,17 @@ class Timecode(object):
     :param start_seconds: A float or integer value showing the seconds.
     :param int frames: Timecode objects can be initialized with an
       integer number showing the total frames.
+    :param force_non_drop_frame: If True, uses Non-Dropframe calculation for
+      29.97 or 59.94 only. Has no meaning for any other framerate.
     """
 
     def __init__(self, framerate, start_timecode=None, start_seconds=None,
-                 frames=None):
+                 frames=None, force_non_drop_frame=False):
+
+        self.force_non_drop_frame = force_non_drop_frame
+
         self.drop_frame = False
+
         self.ms_frame = False
         self.fraction_frame = False
         self._int_framerate = None
@@ -120,11 +136,17 @@ class Timecode(object):
         # set the int_frame_rate
         if framerate == '29.97':
             self._int_framerate = 30
-            self.drop_frame = True
+            if self.force_non_drop_frame is True:
+                self.drop_frame = False
+            else:
+                self.drop_frame = True
         elif framerate == '59.94':
             self._int_framerate = 60
-            self.drop_frame = True
-        elif framerate == '23.98':
+            if self.force_non_drop_frame is True:
+                self.drop_frame = False
+            else:
+                self.drop_frame = True
+        elif framerate in ['23.976', '23.98']:
             framerate = '24'
             self._int_framerate = 24
         elif framerate in ['ms', '1000']:
@@ -202,7 +224,18 @@ class Timecode(object):
              (ifps * seconds) + frames) - \
             (drop_frames * (total_minutes - (total_minutes // 10)))
 
-        frames = frame_number + 1
+        # Special case correction for 29.97 NDF (Non-Dropframe)
+        if self._framerate in {'29.97', '59.94'} and self.drop_frame is False:
+            # Correct for using 30 fps calculation, by converting it to 29.97
+            #   or from 60 fps calculation, by converting it to 59.94
+            # FIXME: Not sure what to do when new frame number is fractional.
+            #  Currently we're just flooring the result, but not sure what we
+            #  should do yet. TBD.
+            corrected_frame_number = frame_number * (ffps / float(ifps))
+            frames = math.ceil(corrected_frame_number) + 1
+
+        else:
+            frames = frame_number + 1
 
         return frames
 
@@ -255,9 +288,9 @@ class Timecode(object):
         if self.fraction_frame:
             frs = round(frs / float(ifps), 3)
 
-        secs = (frame_number // ifps) % 60
-        mins = ((frame_number // ifps) // 60) % 60
-        hrs = (((frame_number // ifps) // 60) // 60)
+        secs = int((frame_number // ifps) % 60)
+        mins = int(((frame_number // ifps) // 60) % 60)
+        hrs = int((((frame_number // ifps) // 60) // 60))
 
         return hrs, mins, secs, frs
 
@@ -284,8 +317,10 @@ class Timecode(object):
         milliseconds/fractionofseconds '00:00:00.000'
         """
         if isinstance(timecode, int):
-            indices = range(2, 10, 2)
-            hrs, mins, secs, frs = [hex(timecode)[i:i + 2] for i in indices]
+            hex_repr = hex(timecode)
+            # fix short string
+            hex_repr = '0x%s' % (hex_repr[2:].zfill(8))
+            hrs, mins, secs, frs = tuple(map(int, [hex_repr[i:i + 2] for i in range(2, 10, 2)]))
 
         else:
             bfr = timecode.replace(';', ':').replace('.', ':').split(':')
@@ -361,6 +396,17 @@ class Timecode(object):
         elif isinstance(other, int):
             return self.frames >= other
 
+    def __gt__(self, other):
+        """override greater operator"""
+        if isinstance(other, Timecode):
+            return self._framerate == other._framerate and \
+                self.frames > other.frames
+        elif isinstance(other, str):
+            new_tc = Timecode(self._framerate, other)
+            return self.frames > new_tc.frames
+        elif isinstance(other, int):
+            return self.frames > other
+
     def __le__(self, other):
         """override less or equal to operator"""
         if isinstance(other, Timecode):
@@ -372,6 +418,17 @@ class Timecode(object):
         elif isinstance(other, int):
             return self.frames <= other
 
+    def __lt__(self, other):
+        """override less operator"""
+        if isinstance(other, Timecode):
+            return self._framerate == other._framerate and \
+                self.frames < other.frames
+        elif isinstance(other, str):
+            new_tc = Timecode(self._framerate, other)
+            return self.frames < new_tc.frames
+        elif isinstance(other, int):
+            return self.frames < other
+
     def __add__(self, other):
         """returns new Timecode instance with the given timecode or frames
         added to this one
@@ -462,6 +519,12 @@ class Timecode(object):
         """
         return self.frames - 1
 
+    @property
+    def float(self):
+        """returns the seconds as float
+        """
+        return float(self.frames) / float(self.framerate)
+
 
 class TimecodeError(Exception):
     """Raised when an error occurred in timecode calculation
